==> org.kikaineko.mock.plugin.kikainekoMocker_1.0.2.zip: org/kikaineko/mock/framework/TargetMethod.java <==
/*
 * 쐬F 2005/08/08
 *
 * TODO ̐ꂽt@C̃ev[gύXɂ͎QƁB
 * EBhE  ݒ  Java  R[hEX^C  R[hEev[g
 */
package org.kikaineko.mock.framework;

import java.util.Vector;

/**
 * @author Masayuki Ioki
 *
 * TODO ̐ꂽ^Rg̃ev[gύXɂ͎QƁB
 * EBhE  ݒ  Java  R[hEX^C  R[hEev[g
 */
class TargetMethod {
    private String visible="public";
    private String name;
    private String returnType;
    private Vector exceptionList;
    private boolean destroyMethodFlag;
    //VOl`[ŁAԂľ^ƂȂ郁\bhꍇ
    //q̌^̂𖳎Kv
    //private boolean ignoreMEthodFlag=false;
    /**
     * 
     */
    public TargetMethod(String name,String returnType) {
        this.name=name;
        this.returnType=returnType;
        exceptionList=new Vector();
    }
    public TargetMethod(String name,String returnType,String[] exceptions) {
        this.name=name;
        this.returnType=returnType;
        exceptionList=new Vector();
        for(int i=0;i<exceptions.length;i++){
        	exceptionList.add(exceptions[i]);
        }
    }
    
    public boolean equals(Object o){
        return this.toString().equals(o.toString());
    }
    
    public String toString(){
        return name;
    }

    /**
     * @return returnType
     */
    public String getReturnType() {
        return returnType;
    }
    /**
     * @param returnType returnType ݒ肵܂B
     */
    public void setReturnType(String returnType) {
        this.returnType = returnType;
    }
    /**
     * @return visible
     */
    public String getVisible() {
        return visible;
    }
    /**
     * @param visible visible ݒ肵܂B
     */
    public void setVisible(String visible) {
        this.visible = visible;
    }
    
    public void addException(String exceptionName){
    	exceptionList.add(exceptionName);
    }
    public boolean hasException(String exceptionName){
    	return exceptionList.contains(exceptionName);
    }
    public String getException(int i){
    	return (String)exceptionList.get(i);
    }
    public int howManyExceptions(){
    	return exceptionList.size();
    }
	public boolean isDestroyMethod() {
		return destroyMethodFlag;
	}
	public void mustBeDestroyMethod() {
		this.destroyMethodFlag = true;
	}
}

==> org.kikaineko.mock.plugin.kikainekoMocker_1.1a.zip: org/kikaineko/mock/framework/TargetMethod.java <==
/*
 * 쐬F 2005/08/08
 *
 * TODO ̐ꂽt@C̃ev[gύXɂ͎QƁB
 * EBhE  ݒ  Java  R[hEX^C  R[hEev[g
 */
package org.kikaineko.mock.framework;

import java.util.Vector;

/**
 * @author Masayuki Ioki
 */
class TargetMethod {
    private String visible="public";
    private String name;
    private String returnType;
    private Vector exceptionList;
    private boolean destroyMethodFlag;
    private boolean isStatic=false;
    //VOl`[ŁAԂľ^ƂȂ郁\bhꍇ
    //q̌^̂𖳎Kv
    //private boolean ignoreMEthodFlag=false;
    /**
     * 
     */
    public TargetMethod(String name,String returnType) {
        this.name=name;
        this.returnType=returnType;
        exceptionList=new Vector();
    }
    public TargetMethod(String name,String returnType,String[] exceptions) {
        this.name=name;
        this.returnType=returnType;
        exceptionList=new Vector();
        for(int i=0;i<exceptions.length;i++){
        	exceptionList.add(exceptions[i]);
        }
    }
    
    public boolean equals(Object o){
        return this.toString().equals(o.toString());
    }
    
    public String toString(){
        return name;
    }

    /**
     * @return returnType
     */
    public String getReturnType() {
        return returnType;
    }
    /**
     * @param returnType returnType ݒ肵܂B
     */
    public void setReturnType(String returnType) {
        this.returnType = returnType;
    }
    /**
     * @return visible
     */
    public String getVisible() {
        return visible;
    }
    /**
     * @param visible visible ݒ肵܂B
     */
    public void setVisible(String visible) {
        this.visible = visible;
    }
    
    public void addException(String exceptionName){
    	exceptionList.add(exceptionName);
    }
    public boolean hasException(String exceptionName){
    	return exceptionList.contains(exceptionName);
    }
    public String getException(int i){
    	return (String)exceptionList.get(i);
    }
    public int howManyExceptions(){
    	return exceptionList.size();
    }
	public boolean isDestroyMethod() {
		return destroyMethodFlag;
	}
	public void mustBeDestroyMethod() {
		this.destroyMethodFlag = true;
	}
	public boolean isStatic() {
		return isStatic;
	}
	public void setStatic(boolean isStatic) {
		this.isStatic = isStatic;
	}
}
